@@ -32,8 +32,7 @@ struct _CountdownHomeWidgetPrivate
     guint refresh;
 	gchar *titleColor, *valueColor;
 	gchar *titleFont, *valueFont;
-	gboolean systemTitle, systemValue;
-	gboolean systemBG, systemButtonArea;
+	gboolean systemFont, systemBG;
 	guint bgOpacity, buttonAreaOpacity;
 	gchar *bgColor, *buttonAreaColor;
 	guint radius;
@@ -101,13 +100,11 @@ void countdown_home_widget_write_settings (CountdownHomeWidget *self)
 	g_key_file_set_string (keyFile, "config", "bgColor", self->priv->bgColor);
 	g_key_file_set_integer (keyFile, "config", "bgOpacity", self->priv->bgOpacity);
 	g_key_file_set_integer (keyFile, "config", "radius", self->priv->radius);
-	g_key_file_set_boolean (keyFile, "config", "systemButtonArea", self->priv->systemButtonArea);
 	g_key_file_set_string (keyFile, "config", "buttonAreaColor", self->priv->buttonAreaColor);
 	g_key_file_set_integer (keyFile, "config", "buttonAreaOpacity", self->priv->buttonAreaOpacity);
-	g_key_file_set_boolean (keyFile, "config", "systemTitle", self->priv->systemTitle);
+	g_key_file_set_boolean (keyFile, "config", "systemFont", self->priv->systemFont);
 	g_key_file_set_string (keyFile, "config", "titleColor", self->priv->titleColor);
 	g_key_file_set_string (keyFile, "config", "titleFont", self->priv->titleFont);
-	g_key_file_set_boolean (keyFile, "config", "systemValue", self->priv->systemValue);
 	g_key_file_set_string (keyFile, "config", "valueColor", self->priv->valueColor);
 	g_key_file_set_string (keyFile, "config", "valueFont", self->priv->valueFont);
 	
@@ -570,32 +567,24 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 {
 	//g_warning ("countdown_home_widget_global_options");
     GtkWidget *dialog, *content_area;
-    GtkWidget *refreshButton, *titleSettingsButton, *valueSettingsButton;
-	GtkWidget *bgSettingsButton, *buttonAreaSettingsButton;
-    GtkWidget *refreshCaption, *titleSettingsCaption, *valueSettingsCaption;
-	GtkWidget *bgSettingsCaption, *buttonAreaSettingsCaption;
-	GtkWidget *titleDialog, *valueDialog, *bgDialog, *buttonAreaDialog;
-	GtkWidget *titleContentArea, *valueContentArea, *bgContentArea, *buttonAreaContentArea;
+    GtkWidget *refreshButton, *fontSettingsButton;
+	GtkWidget *bgSettingsButton;
+    GtkWidget *refreshCaption, *fontSettingsCaption;
+	GtkWidget *bgSettingsCaption;
+	GtkWidget *fontDialog, *bgDialog;
+	GtkWidget *fontContentArea, *bgContentArea;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	GtkSizeGroup *titleGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	GtkSizeGroup *valueGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	GtkSizeGroup *fontGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	GtkSizeGroup *bgGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	GtkSizeGroup *buttonAreaGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	GdkColor color;
 	
-	titleSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	valueSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	fontSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 	bgSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	buttonAreaSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 
     dialog = gtk_dialog_new_with_buttons ("Countdown Settings",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
         "Save", GTK_RESPONSE_ACCEPT, NULL);
-    GtkWidget *dialogContentArea = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-	GtkWidget *scroll = hildon_pannable_area_new ();
-	content_area = gtk_vbox_new (FALSE, 0);
-	hildon_pannable_area_add_with_viewport (HILDON_PANNABLE_AREA (scroll), content_area);
-	gtk_container_add (GTK_CONTAINER (dialogContentArea), scroll);
+    content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
     
 	GtkWidget *picker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
 	gtk_window_set_title (GTK_WINDOW (picker), "Update Every");
@@ -610,59 +599,47 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	}
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, self->priv->refresh);
 	
-	titleDialog = gtk_dialog_new_with_buttons ("Title Settings", dialog,
+	fontDialog = gtk_dialog_new_with_buttons ("Font Settings", dialog,
 		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
-	titleContentArea = gtk_dialog_get_content_area (GTK_DIALOG (titleDialog));
+	fontContentArea = gtk_dialog_get_content_area (GTK_DIALOG (fontDialog));
 	
-	GtkWidget *titleSystemStyle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (titleSystemStyle), "Use system style");
-	hildon_check_button_set_active (HILDON_CHECK_BUTTON (titleSystemStyle), self->priv->systemTitle);
-	g_signal_connect (titleSystemStyle, "toggled", G_CALLBACK (countdown_home_widget_system_settings), titleSettingsButton);
-	GtkWidget *titleSystemStyleCaption = hildon_caption_new (titleGroup, "", titleSystemStyle, NULL, HILDON_CAPTION_MANDATORY);
-	hildon_caption_set_separator (HILDON_CAPTION (titleSystemStyleCaption), "");
-	gtk_container_add (GTK_CONTAINER (titleContentArea), titleSystemStyleCaption);
+	GtkWidget *fontSystemStyle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (fontSystemStyle), "Use system style");
+	hildon_check_button_set_active (HILDON_CHECK_BUTTON (fontSystemStyle), self->priv->systemFont);
+	g_signal_connect (fontSystemStyle, "toggled", G_CALLBACK (countdown_home_widget_system_settings), fontSettingsButton);
+	GtkWidget *fontSystemStyleCaption = hildon_caption_new (fontGroup, "", fontSystemStyle, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (fontSystemStyleCaption), "");
+	gtk_container_add (GTK_CONTAINER (fontContentArea), fontSystemStyleCaption);
 	
 	GtkWidget *titleColorButton = gtk_color_button_new ();
 	gdk_color_parse (self->priv->titleColor, &color);
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (titleColorButton), &color);
 	hildon_gtk_widget_set_theme_size (titleColorButton, HILDON_SIZE_FINGER_HEIGHT);
-	GtkWidget *titleColorCaption = hildon_caption_new (titleGroup, "Font color", titleColorButton, NULL, HILDON_CAPTION_MANDATORY);
+	GtkWidget *titleColorCaption = hildon_caption_new (fontGroup, "Title color", titleColorButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (titleColorCaption), "");
-	gtk_container_add (GTK_CONTAINER (titleContentArea), titleColorCaption);
+	gtk_container_add (GTK_CONTAINER (fontContentArea), titleColorCaption);
 	
 	GtkWidget *titleFontButton = gtk_font_button_new ();
 	gtk_font_button_set_font_name (GTK_FONT_BUTTON (titleFontButton), self->priv->titleFont);
 	hildon_gtk_widget_set_theme_size (titleFontButton, HILDON_SIZE_FINGER_HEIGHT);
-	GtkWidget *titleFontCaption = hildon_caption_new (titleGroup, "Font style", titleFontButton, NULL, HILDON_CAPTION_MANDATORY);
+	GtkWidget *titleFontCaption = hildon_caption_new (fontGroup, "Title font", titleFontButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (titleFontCaption), "");
-	gtk_container_add (GTK_CONTAINER (titleContentArea), titleFontCaption);
-	
-	valueDialog = gtk_dialog_new_with_buttons ("Value Settings", dialog,
-		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
-	valueContentArea = gtk_dialog_get_content_area (GTK_DIALOG (valueDialog));	
-	
-	GtkWidget *valueSystemStyle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (valueSystemStyle), "Use system style");
-	hildon_check_button_set_active (HILDON_CHECK_BUTTON (valueSystemStyle), self->priv->systemValue);
-	g_signal_connect (valueSystemStyle, "toggled", G_CALLBACK (countdown_home_widget_system_settings), valueSettingsButton);
-	GtkWidget *valueSystemStyleCaption = hildon_caption_new (valueGroup, "", valueSystemStyle, NULL, HILDON_CAPTION_MANDATORY);
-	hildon_caption_set_separator (HILDON_CAPTION (valueSystemStyleCaption), "");
-	gtk_container_add (GTK_CONTAINER (valueContentArea), valueSystemStyleCaption);	
+	gtk_container_add (GTK_CONTAINER (fontContentArea), titleFontCaption);
 	
 	GtkWidget *valueColorButton = gtk_color_button_new ();
 	gdk_color_parse (self->priv->valueColor, &color);
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (valueColorButton), &color);
 	hildon_gtk_widget_set_theme_size (valueColorButton, HILDON_SIZE_FINGER_HEIGHT);
-	GtkWidget *valueColorCaption = hildon_caption_new (valueGroup, "Font color", valueColorButton, NULL, HILDON_CAPTION_MANDATORY);
+	GtkWidget *valueColorCaption = hildon_caption_new (fontGroup, "Value color", valueColorButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (valueColorCaption), "");
-	gtk_container_add (GTK_CONTAINER (valueContentArea), valueColorCaption);
+	gtk_container_add (GTK_CONTAINER (fontContentArea), valueColorCaption);
 	
 	GtkWidget *valueFontButton = gtk_font_button_new ();
 	gtk_font_button_set_font_name (GTK_FONT_BUTTON (valueFontButton), self->priv->valueFont);
 	hildon_gtk_widget_set_theme_size (valueFontButton, HILDON_SIZE_FINGER_HEIGHT);
-	GtkWidget *valueFontCaption = hildon_caption_new (valueGroup, "Font style", valueFontButton, NULL, HILDON_CAPTION_MANDATORY);
+	GtkWidget *valueFontCaption = hildon_caption_new (fontGroup, "Value font", valueFontButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (valueFontCaption), "");
-	gtk_container_add (GTK_CONTAINER (valueContentArea), valueFontCaption);
+	gtk_container_add (GTK_CONTAINER (fontContentArea), valueFontCaption);
 	
 	bgDialog = gtk_dialog_new_with_buttons ("Background Settings", dialog,
 		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
@@ -703,29 +680,17 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	GtkWidget *bgOpacityCaption = hildon_caption_new (bgGroup, "Background opacity", bgOpacityButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (bgOpacityCaption), "");
 	gtk_container_add (GTK_CONTAINER (bgContentArea), bgOpacityCaption);
-	
-	buttonAreaDialog = gtk_dialog_new_with_buttons ("Button Area Settings", dialog,
-		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
-	buttonAreaContentArea = gtk_dialog_get_content_area (GTK_DIALOG (buttonAreaDialog));
-	
-	GtkWidget *buttonAreaSystemStyle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (buttonAreaSystemStyle), "Use system style");
-	hildon_check_button_set_active (HILDON_CHECK_BUTTON (buttonAreaSystemStyle), self->priv->systemButtonArea);
-	g_signal_connect (buttonAreaSystemStyle, "toggled", G_CALLBACK (countdown_home_widget_system_settings), buttonAreaSettingsButton);
-	GtkWidget *buttonAreaSystemStyleCaption = hildon_caption_new (buttonAreaGroup, "", buttonAreaSystemStyle, NULL, HILDON_CAPTION_MANDATORY);
-	hildon_caption_set_separator (HILDON_CAPTION (buttonAreaSystemStyleCaption), "");
-	gtk_container_add (GTK_CONTAINER (buttonAreaContentArea), buttonAreaSystemStyleCaption);	
-	
+		
 	GtkWidget *buttonAreaColorButton = gtk_color_button_new ();
 	gdk_color_parse (self->priv->buttonAreaColor, &color);
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (buttonAreaColorButton), &color);
 	hildon_gtk_widget_set_theme_size (buttonAreaColorButton, HILDON_SIZE_FINGER_HEIGHT);
-	GtkWidget *buttonAreaColorCaption = hildon_caption_new (buttonAreaGroup, "Background color", buttonAreaColorButton, NULL, HILDON_CAPTION_MANDATORY);
+	GtkWidget *buttonAreaColorCaption = hildon_caption_new (bgGroup, "Button area color", buttonAreaColorButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (buttonAreaColorCaption), "");
-	gtk_container_add (GTK_CONTAINER (buttonAreaContentArea), buttonAreaColorCaption);
+	gtk_container_add (GTK_CONTAINER (bgContentArea), buttonAreaColorCaption);
 	
-	GtkWidget *buttonAreaOpacityPicker = hildon_picker_dialog_new (GTK_WINDOW (buttonAreaDialog));
-	gtk_window_set_title (GTK_WINDOW (buttonAreaOpacityPicker), "Background opacity");
+	GtkWidget *buttonAreaOpacityPicker = hildon_picker_dialog_new (GTK_WINDOW (bgDialog));
+	gtk_window_set_title (GTK_WINDOW (buttonAreaOpacityPicker), "Button area opacity");
 	GtkWidget *buttonAreaOpacitySelector = hildon_touch_selector_new_text ();
 	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (buttonAreaOpacityPicker), HILDON_TOUCH_SELECTOR (buttonAreaOpacitySelector));
 	
@@ -740,66 +705,11 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	name = g_strdup_printf ("%d%%", self->priv->buttonAreaOpacity);
 	gtk_button_set_label (GTK_BUTTON (buttonAreaOpacityButton), name);
 	g_free (name);
-	GtkWidget *buttonAreaOpacityCaption = hildon_caption_new (buttonAreaGroup, "Background opacity", buttonAreaOpacityButton, NULL, HILDON_CAPTION_MANDATORY);
+	GtkWidget *buttonAreaOpacityCaption = hildon_caption_new (bgGroup, "Button area opacity", buttonAreaOpacityButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (buttonAreaOpacityCaption), "");
-	gtk_container_add (GTK_CONTAINER (buttonAreaContentArea), buttonAreaOpacityCaption);
+	gtk_container_add (GTK_CONTAINER (bgContentArea), buttonAreaOpacityCaption);
 	
-	refreshButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	g_signal_connect (G_OBJECT (refreshButton), "clicked", G_CALLBACK (countdown_home_widget_select_refresh), picker);
-	
-	gchar *text = g_strdup_printf ("%d minute(s)", self->priv->refresh);
-	gtk_button_set_label (GTK_BUTTON (refreshButton), text);
-	g_free (text);
-	
-	refreshCaption = hildon_caption_new (group, "Update every", refreshButton, NULL, HILDON_CAPTION_MANDATORY);
-	hildon_caption_set_separator (HILDON_CAPTION (refreshCaption), "");
-    gtk_container_add (GTK_CONTAINER (content_area), refreshCaption);
-	
-	if (self->priv->systemTitle) {
-		gtk_button_set_label (GTK_BUTTON (titleSettingsButton), "System style");
-	} else {
-		gtk_button_set_label (GTK_BUTTON (titleSettingsButton), "User style");
-	}
-	g_signal_connect (titleSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_title_settings), titleDialog);
-	
-	titleSettingsCaption = hildon_caption_new (group, "Title", titleSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
-	hildon_caption_set_separator (HILDON_CAPTION (titleSettingsCaption), "");
-	gtk_container_add (GTK_CONTAINER (content_area), titleSettingsCaption);
-
-	if (self->priv->systemValue) {
-		gtk_button_set_label (GTK_BUTTON (valueSettingsButton), "System style");
-	} else {
-		gtk_button_set_label (GTK_BUTTON (valueSettingsButton), "User style");
-	}
-	g_signal_connect (valueSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_value_settings), valueDialog);
-	
-	valueSettingsCaption = hildon_caption_new (group, "Value", valueSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
-	hildon_caption_set_separator (HILDON_CAPTION (valueSettingsCaption), "");
-	gtk_container_add (GTK_CONTAINER (content_area), valueSettingsCaption);
-	
-	if (self->priv->systemBG) {
-		gtk_button_set_label (GTK_BUTTON (bgSettingsButton), "System style");
-	} else {
-		gtk_button_set_label (GTK_BUTTON (bgSettingsButton), "User style");
-	}
-	g_signal_connect (bgSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_bg_settings), bgDialog);
-
-	bgSettingsCaption = hildon_caption_new (group, "Background", bgSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
-	hildon_caption_set_separator (HILDON_CAPTION (bgSettingsCaption), "");
-	gtk_container_add (GTK_CONTAINER (content_area), bgSettingsCaption);	
-
-	if (self->priv->systemButtonArea) {
-		gtk_button_set_label (GTK_BUTTON (buttonAreaSettingsButton), "System style");
-	} else {
-		gtk_button_set_label (GTK_BUTTON (buttonAreaSettingsButton), "User style");
-	}
-	g_signal_connect (buttonAreaSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_bg_settings), buttonAreaDialog);
-
-	buttonAreaSettingsCaption = hildon_caption_new (group, "Button area", buttonAreaSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
-	hildon_caption_set_separator (HILDON_CAPTION (buttonAreaSettingsCaption), "");
-	gtk_container_add (GTK_CONTAINER (content_area), buttonAreaSettingsCaption);	
-
-	GtkWidget *radiusPicker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
+	GtkWidget *radiusPicker = hildon_picker_dialog_new (GTK_WINDOW (bgDialog));
 	gtk_window_set_title (GTK_WINDOW (radiusPicker), "Corner radius");
 	GtkWidget *radiusSelector = hildon_touch_selector_new_text ();
 	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (radiusPicker), HILDON_TOUCH_SELECTOR (radiusSelector));
@@ -815,11 +725,42 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	name = g_strdup_printf ("%d", self->priv->radius);
 	gtk_button_set_label (GTK_BUTTON (radiusButton), name);
 	g_free (name);
-	GtkWidget *radiusCaption = hildon_caption_new (group, "Corner radius", radiusButton, NULL, HILDON_CAPTION_MANDATORY);
+	GtkWidget *radiusCaption = hildon_caption_new (bgGroup, "Corner radius", radiusButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (radiusCaption), "");
-	gtk_container_add (GTK_CONTAINER (content_area), radiusCaption);
+	gtk_container_add (GTK_CONTAINER (bgContentArea), radiusCaption);
+	
+	refreshButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	g_signal_connect (G_OBJECT (refreshButton), "clicked", G_CALLBACK (countdown_home_widget_select_refresh), picker);
+	
+	gchar *text = g_strdup_printf ("%d minute(s)", self->priv->refresh);
+	gtk_button_set_label (GTK_BUTTON (refreshButton), text);
+	g_free (text);
+	
+	refreshCaption = hildon_caption_new (group, "Update every", refreshButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (refreshCaption), "");
+    gtk_container_add (GTK_CONTAINER (content_area), refreshCaption);
+	
+	if (self->priv->systemFont) {
+		gtk_button_set_label (GTK_BUTTON (fontSettingsButton), "System style");
+	} else {
+		gtk_button_set_label (GTK_BUTTON (fontSettingsButton), "User style");
+	}
+	g_signal_connect (fontSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_title_settings), fontDialog);
+	
+	fontSettingsCaption = hildon_caption_new (group, "Title", fontSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (fontSettingsCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), fontSettingsCaption);
 
-	gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 300);
+	if (self->priv->systemBG) {
+		gtk_button_set_label (GTK_BUTTON (bgSettingsButton), "System style");
+	} else {
+		gtk_button_set_label (GTK_BUTTON (bgSettingsButton), "User style");
+	}
+	g_signal_connect (bgSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_bg_settings), bgDialog);
+
+	bgSettingsCaption = hildon_caption_new (group, "Background", bgSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (bgSettingsCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), bgSettingsCaption);	
 
     gtk_widget_show_all (dialog);
 
@@ -828,12 +769,11 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 		GdkColor color;
 		self->priv->refresh = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
 		
-		self->priv->systemTitle = hildon_check_button_get_active (HILDON_CHECK_BUTTON (titleSystemStyle));
+		self->priv->systemFont = hildon_check_button_get_active (HILDON_CHECK_BUTTON (fontSystemStyle));
 		gtk_color_button_get_color (GTK_COLOR_BUTTON (titleColorButton), &color);
 		self->priv->titleColor = gdk_color_to_string (&color);
 		self->priv->titleFont = g_markup_escape_text(gtk_font_button_get_font_name (GTK_FONT_BUTTON (titleFontButton)), -1);
 		
-		self->priv->systemValue = hildon_check_button_get_active (HILDON_CHECK_BUTTON (valueSystemStyle));
 		gtk_color_button_get_color (GTK_COLOR_BUTTON (valueColorButton), &color);
 		self->priv->valueColor = gdk_color_to_string (&color);
 		self->priv->valueFont = g_markup_escape_text(gtk_font_button_get_font_name (GTK_FONT_BUTTON (valueFontButton)), -1);
@@ -842,10 +782,8 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 		gtk_color_button_get_color (GTK_COLOR_BUTTON (bgColorButton), &color);
 		self->priv->bgColor = gdk_color_to_string (&color);
 		self->priv->bgOpacity = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (bgOpacitySelector), 0);
-		
 		self->priv->radius = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (radiusSelector), 0);
 		
-		self->priv->systemButtonArea = hildon_check_button_get_active (HILDON_CHECK_BUTTON (buttonAreaSystemStyle));
 		gtk_color_button_get_color (GTK_COLOR_BUTTON (buttonAreaColorButton), &color);
 		self->priv->buttonAreaColor = gdk_color_to_string (&color);
 		self->priv->buttonAreaOpacity = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (buttonAreaOpacitySelector), 0);
@@ -963,12 +901,6 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 			g_error_free (error);
 			error = NULL;
 		}
-		self->priv->systemButtonArea = g_key_file_get_boolean (keyFile, "config", "systemButtonArea", &error);
-		if (error) {
-			self->priv->systemButtonArea = TRUE;
-			g_error_free (error);
-			error = NULL;
-		}
 		self->priv->buttonAreaColor = g_key_file_get_string (keyFile, "config", "buttonAreaColor", &error);
 		if (error) {
 			self->priv->buttonAreaColor = "#000000";
@@ -981,9 +913,9 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 			g_error_free (error);
 			error = NULL;
 		}
-		self->priv->systemTitle = g_key_file_get_boolean (keyFile, "config", "systemTitle", &error);
+		self->priv->systemFont = g_key_file_get_boolean (keyFile, "config", "systemFont", &error);
 		if (error) {
-			self->priv->systemTitle = TRUE;
+			self->priv->systemFont = TRUE;
 			g_error_free (error);
 			error = NULL;
 		}
@@ -999,12 +931,6 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 			g_error_free (error);
 			error = NULL;
 		}
-		self->priv->systemValue = g_key_file_get_boolean (keyFile, "config", "systemValue", &error);
-		if (error) {
-			self->priv->systemValue = TRUE;
-			g_error_free (error);
-			error = NULL;
-		}
 		self->priv->valueColor = g_key_file_get_string (keyFile, "config", "valueColor", &error);
 		if (error) {
 			self->priv->valueColor = "#ababab";
@@ -1023,13 +949,11 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 		self->priv->bgOpacity = 25;
 		self->priv->bgColor = "#000000";
 		self->priv->radius = 10;
-		self->priv->systemButtonArea = TRUE;
 		self->priv->buttonAreaOpacity = 50;
 		self->priv->buttonAreaColor = "#000000";
-		self->priv->systemTitle = TRUE;
+		self->priv->systemFont = TRUE;
 		self->priv->titleColor = "#ffffff";
 		self->priv->titleFont = "Sans 18";
-		self->priv->systemValue = TRUE;
 		self->priv->valueColor = "#ababab";
 		self->priv->valueFont = "Sans 16";
     }
@@ -1234,13 +1158,13 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 			GtkWidget *vbox = gtk_vbox_new (TRUE, 0);
 			GtkWidget *titleLabel = gtk_label_new (title);
 			gtk_label_set_ellipsize (GTK_LABEL (titleLabel), PANGO_ELLIPSIZE_END);
-			if (!self->priv->systemTitle) {
+			if (!self->priv->systemFont) {
 				gtk_label_set_markup (GTK_LABEL (titleLabel), g_strconcat ("<span font=\"", self->priv->titleFont,"\" color=\"",self->priv->titleColor, "\">", title, "</span>", NULL));
 			}
 			GtkWidget *contentLabel = gtk_label_new (contentLabelText);
 			gtk_label_set_ellipsize (GTK_LABEL (contentLabel), PANGO_ELLIPSIZE_END);
 			
-			if (self->priv->systemValue) {
+			if (self->priv->systemFont) {
 				GdkColor color;
 				gtk_style_lookup_color (gtk_rc_get_style(contentLabel), "SecondaryTextColor", &color);
 				gtk_label_set_markup (GTK_LABEL (contentLabel), g_strconcat ("<span size=\"smaller\" color=\"",gdk_color_to_string (&color),"\">", contentLabelText, "</span>", NULL));
@@ -1367,7 +1291,7 @@ static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, Gdk
 	cairo_clip (cr);
 
     cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-	if (self->priv->systemButtonArea) {
+	if (self->priv->systemBG) {
 		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
 	} else {
 		GdkColor color;
