@@ -25,25 +25,24 @@ G_BEGIN_DECLS
 #define COUNTDOWN_HOME_WIDGET_GET_CLASS(obj) \
   (G_TYPE_INSTANCE_GET_CLASS ((obj), COUNTDOWN_TYPE_HOME_WIDGET, CountdownHomeWidgetClass))
 
-typedef struct {
-    HDHomePluginItem hitem;
-    GtkWidget *homeWidget;
-    GtkWidget *contents;
-	GtkWidget *upButton, *downButton;
-    GtkListStore *entries;
-    guint refresh;
-	guint offset;
-    guint eventID;
-} CountdownHomeWidget;
+typedef struct _CountdownHomeWidget        CountdownHomeWidget;
+typedef struct _CountdownHomeWidgetClass   CountdownHomeWidgetClass;
+typedef struct _CountdownHomeWidgetPrivate CountdownHomeWidgetPrivate;
 
-typedef struct {
-  HDHomePluginItemClass parent_class;
-} CountdownHomeWidgetClass;
+struct _CountdownHomeWidget
+{
+  HDHomePluginItem parent;
+
+  CountdownHomeWidgetPrivate *priv;
+};
+
+struct _CountdownHomeWidgetClass
+{
+  HDHomePluginItemClass  parent;
+};
 
 GType countdown_home_widget_get_type (void);
 
-CountdownHomeWidget* countdown_home_widget_new (void);
-
 G_END_DECLS
 
 #endif /* _COUNTDOWN_HOME_WIDGET */
